<?php

class ImgImporter {

  private $supported_types;
  private $img;
  private $thumbnail;

  function __construct() {
    $this->supported_types=array('jpg', 'jpeg', 'png', 'gif');
    $this->img["max_x"]=0;
    $this->img["max_y"]=640;
    $this->thumbnail["max_x"]=0;
    $this->thumbnail["max_y"]=75;
  }

  function show_koncovky(){
    return $this->supported_types;
  }

  function copyImage($old_name, $new_name, $new_name_tmb){
    //vytvoření složky
    if (!is_dir(dirname($new_name))) {
      if (!$this->mkdir_p(dirname($new_name), 0755, 1)) {
        return FALSE;
      }
    }

    //výpočet velikosti img
    list($width, $height) = $this->image_shrink_size($old_name, $this->img["max_x"], $this->img["max_y"]);
    if ($width && $height){
        if (!$this->image_resize($old_name, $new_name, $width, $height))
            return FALSE;
    }
    else return FALSE;

    //výpočet velikosti thmb
    list($width, $height) = $this->image_shrink_size($old_name, $this->thumbnail["max_x"], $this->thumbnail["max_y"]);
    if ($width && $height){
        if (!$this->image_resize($old_name, $new_name_tmb, $width, $height))
            return FALSE;
    }
    else return FALSE;

    return TRUE;
  }

  /* Vrácení rozměrů obrázku po zmenšení
  @param string $file_in název zmenšovaného souboru
  @param int [$max_x] maximální šířka výsledného obrázku, 0 pokud na ní nezáleží
  @param int [$max_y] maximální výška výsledného obrázku, 0 pokud na ní nezáleží
  @return array ($width, $height) výsledná šířka a výška
  */

  protected function image_shrink_size($file_in, $max_x = 0, $max_y = 0) {
      list($width, $height) = getimagesize($file_in);
      if (!$width || !$height) {
         return array(0, 0);
      }
      if ($max_x && $width > $max_x) {
          $height = round($height * $max_x / $width);
          $width = $max_x;
      }
      if ($max_y && $height > $max_y) {
          $width = round($width * $max_y / $height);
          $height = $max_y;
      }
      return array($width, $height);
  }

  /*Převzorkování obrázku GIF, PNG nebo JPG
    @param string $file_in název zmenšovaného souboru
    @param string $file_out název výsledného souboru
    @param int $width šířka výsledného obrázku
    @param int $height výška výsledného obrázku
    @return bool true, false v případě chyby
  */

  protected function image_resize($file_in, $file_out, $width, $height) {
      $imagesize = getimagesize($file_in);
      if ((!$width && !$height) || !$imagesize[0] || !$imagesize[1]) {
          return false;
      }
      if ($imagesize[0] == $width && $imagesize[1] == $height) {
        return copy($file_in, $file_out);
      }
      switch ($imagesize[2]) {
          case 1: $img = imagecreatefromgif($file_in); break;
          case 2: $img = imagecreatefromjpeg($file_in); break;
          case 3: $img = imagecreatefrompng($file_in); break;
          default: return false;
      }
      if (!$img) {
          return false;
      }
      $img2 = imagecreatetruecolor($width, $height);
      imagecopyresampled($img2, $img, 0, 0, 0, 0, $width, $height, $imagesize[0], $imagesize[1]);
      if ($imagesize[2] == 2) {
          return imagejpeg($img2, $file_out);
      } elseif ($imagesize[2] == 1 && function_exists("imagegif")) {
          imagetruecolortopalette($img2, false, 256);
          return imagegif($img2, $file_out);
      } else {
          return imagepng($img2, $file_out);
      }
  }

  protected function mkdir_p($target) {
    $target= preg_replace("/^\/\//", "/", $target);
    if (mkdir($target, 0755, 1)) {
      return TRUE;
    }
    return FALSE;
  }
}