<?php
class MyDb {
  protected $mysqli;
  protected $showerror = TRUE;   // nastavte FALSE, pokud nechcete zobrazovat chybová hlášení
  protected $showsql   = FALSE;  // nastavte TRUE, pokud chcete kvůli ladění zobrazovat všechny dotazy SQL
  protected $sqlcounter = 0;     // počítadlo příkazů SQL
  protected $rowcounter = 0;     // počítadlo vrácených řádků SELECT
  protected $dbtime     = 0;     // počítadlo času potřebného pro vykonání dotazů
  protected $starttime;

    // konstruktor
  function __construct() {
    require_once(dirname(__FILE__).'/../_private/password.php');
    $this->mysqli = @new mysqli($mysqlhost, $mysqluser, $mysqlpasswd, $mysqldb);
    $this->mysqli->set_charset('utf8');
    if(mysqli_connect_errno()) {
      $this->printerror("Spojení nebylo navázáno! (" . mysqli_connect_error() . ")");
      $this->mysqli = FALSE;
      exit();
    }
    $this->starttime = $this->microtime_float();
  }

  // destruktor
  function __destruct() {
    $this->close();
   }

  // dodatečné uzavření
  function close() {
    if($this->mysqli)
      $this->mysqli->close();
      $this->mysqli = FALSE;
  }
  
  function getMysqli() {
    return $this->mysqli; }

  // vykonání dotazu SELECT, vrací se pole
  function queryObjectArray($sql) {
    $this->sqlcounter++;
    $this->printsql($sql);
    $time1  = $this->microtime_float();
    $result = $this->mysqli->query($sql);
    $time2  = $this->microtime_float();
    $this->dbtime += ($time2 - $time1);
    if($result) {
      if($result->num_rows) {
        while($row = $result->fetch_object())
          $result_array[] = $row;
        $this->rowcounter += sizeof($result_array);
        return $result_array; }
      else
        return FALSE;
    } else {
      $this->printerror($this->mysqli->error);
      return FALSE;
    }
  }

  // vykonání dotazu SELECT, vrací se pole

    function queryArray($sql) {
    $this->sqlcounter++;
    $this->printsql($sql);
    $time1  = $this->microtime_float();
    $result = $this->mysqli->query($sql);
    $time2  = $this->microtime_float();
    $this->dbtime += ($time2 - $time1);
    if($result) {
      if($result->num_rows) {
         while($row = $result->fetch_array())
            $result_array[] = $row;
        $this->rowcounter += sizeof($result_array);
        return $result_array;
       }
      else
        return FALSE;
    } else {
      $this->printerror($this->mysqli->error);
      return FALSE;
    }
  }

  // vykonání dotazu SELECT, který vrací pouze jednu položku
  // (tj. SELECT COUNT(*) FROM table); vrací
  // tuto poloľku
  // pozor: tato metoda při chybě vrací hodnotu -1 (a nikoliv 0)!
  function querySingleItem($sql) {
    $this->sqlcounter++;
    $this->printsql($sql);
    $time1  = $this->microtime_float();
    $result = $this->mysqli->query($sql);
    $time2  = $this->microtime_float();
    $this->dbtime += ($time2 - $time1);
    if($result) {
      if ($row=$result->fetch_array()) {
        $result->close();
        $this->rowcounter++;
        return $row[0];
      } else {
        // dotaz nevrátil ľádná data
        return -1;
      }
    } else {
      $this->printerror($this->mysqli->error);
      return -1;
    }
  }

  // vykonání příkazu SQL bez výsledků (žádný dotaz)
  function execute($sql) {
    $this->sqlcounter++;
    $this->printsql($sql);
    $time1  = $this->microtime_float();
    $result = $this->mysqli->real_query($sql);
    $time2  = $this->microtime_float();
    $this->dbtime += ($time2 - $time1);
    if($result)
      return TRUE;
    else {
      $this->printerror($this->mysqli->error);
      return FALSE;
    }
  }

  // použití insert_id za příkazem INSERT
  function insertId() {
    return $this->mysqli->insert_id;
  }

  // vložení \ před ', " atd.
  function escape($txt) {
    return trim($this->mysqli->escape_string($txt));
  }

  // vrací hodnotu 'NULL' nebo '<quoted string>'
  function sql_string($txt) {
    if(!$txt || trim($txt)=="")
      return 'NULL';
    else
      return "'" . $this->escape(trim($txt)) . "'";
  }
  
  function error() {
    return $this->mysqli->error; }

  private function printsql($sql) {
    if($this->showsql)
      printf("<p><font color=\"#0000ff\">%s</font></p>\n",
        htmlentities($sql));
  }

  private function printerror($txt) {
    if($this->showerror)
      printf("<p><font color=\"#ff0000\">%s</font></p>\n",
        htmlentities($txt));
  }

  private function microtime_float() {
    list($usec, $sec) = explode(" ", microtime());
    return ((float)$usec + (float)$sec);
  }

  function showStatistics() {
    $totalTime = $this->microtime_float() - $this->starttime;
    printf("<p><font color=\"#0000ff\">Příkazy SQL: %d\n",
      $this->sqlcounter);
    printf("<br />Součet vracených řádků: %d\n",
      $this->rowcounter);
    printf("<br />Čas vykonávání dotazů (MySQL): %f\n",
      $this->dbtime);
    printf("<br />Doba zpracování (PHP): %f\n",
      $totalTime - $this->dbtime);
    printf("<br />Celkový čas od vytvoření MyDB / poslední reset: %f</font></p>\n",
      $totalTime);
   }

  function resetStatistics() {
    $this->sqlcounter = 0;
    $this->rowcounter = 0;
    $this->dbtime     = 0;
    $this->starttime = $this->microtime_float();
  }

}

?>
