SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `moto_111406` DEFAULT CHARACTER SET utf8 COLLATE utf8_czech_ci ;
USE `moto_111406` ;

-- -----------------------------------------------------
-- Table `moto_111406`.`Uzivatel`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Uzivatel` (
  `idUzivatel` INT NOT NULL AUTO_INCREMENT ,
  `Nick` VARCHAR(45) NOT NULL ,
  `email` VARCHAR(45) NOT NULL ,
  `telefon` INT(9) NOT NULL ,
  `icq` INT(9) NULL ,
  `Heslo` CHAR(41) NOT NULL ,
  `active` TINYINT(4) NOT NULL DEFAULT 0 ,
  `authent` VARCHAR(50) NOT NULL ,
  `ts` TIMESTAMP NOT NULL ,
  PRIMARY KEY (`idUzivatel`) ,
  UNIQUE INDEX `idUzivatel_UNIQUE` (`idUzivatel` ASC) ,
  UNIQUE INDEX `Nick_UNIQUE` (`Nick` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Kraj`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Kraj` (
  `idKraj` INT NOT NULL AUTO_INCREMENT ,
  `Kraj` VARCHAR(45) NOT NULL ,
  PRIMARY KEY (`idKraj`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Mesto`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Mesto` (
  `idMesto` INT NOT NULL AUTO_INCREMENT ,
  `Mesto` VARCHAR(45) NOT NULL ,
  `Kraj_idKraj` INT NOT NULL ,
  PRIMARY KEY (`idMesto`) ,
  INDEX `fk_Mesto_Kraj1` (`Kraj_idKraj` ASC) ,
  CONSTRAINT `fk_Mesto_Kraj1`
    FOREIGN KEY (`Kraj_idKraj` )
    REFERENCES `moto_111406`.`Kraj` (`idKraj` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Mesto_uzivatel`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Mesto_uzivatel` (
  `Uzivatel_idUzivatel` INT NOT NULL ,
  `Mesto_idMesto` INT NOT NULL ,
  PRIMARY KEY (`Uzivatel_idUzivatel`, `Mesto_idMesto`) ,
  INDEX `fk_Adresa_uzivatel_Mesto1` (`Mesto_idMesto` ASC) ,
  CONSTRAINT `fk_Adresa_uzivatel_Uzivatel1`
    FOREIGN KEY (`Uzivatel_idUzivatel` )
    REFERENCES `moto_111406`.`Uzivatel` (`idUzivatel` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Adresa_uzivatel_Mesto1`
    FOREIGN KEY (`Mesto_idMesto` )
    REFERENCES `moto_111406`.`Mesto` (`idMesto` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Znacka`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Znacka` (
  `idZnacka` INT NOT NULL AUTO_INCREMENT ,
  `Znacka` VARCHAR(30) NOT NULL ,
  PRIMARY KEY (`idZnacka`) ,
  UNIQUE INDEX `Znacka_UNIQUE` (`Znacka` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Kategorie`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Kategorie` (
  `idKategorie` INT NOT NULL AUTO_INCREMENT ,
  `Kategorie` VARCHAR(30) NOT NULL ,
  PRIMARY KEY (`idKategorie`) ,
  UNIQUE INDEX `Kategorie_UNIQUE` (`Kategorie` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Model`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Model` (
  `idModel` INT NOT NULL AUTO_INCREMENT ,
  `Model` VARCHAR(30) NOT NULL ,
  `Znacka_idZnacka` INT NOT NULL ,
  `Kategorie_idKategorie` INT NOT NULL ,
  PRIMARY KEY (`idModel`) ,
  INDEX `fk_Typ_Znacka1` (`Znacka_idZnacka` ASC) ,
  INDEX `fk_Typ_Kategorie1` (`Kategorie_idKategorie` ASC) ,
  CONSTRAINT `fk_Typ_Znacka1`
    FOREIGN KEY (`Znacka_idZnacka` )
    REFERENCES `moto_111406`.`Znacka` (`idZnacka` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Typ_Kategorie1`
    FOREIGN KEY (`Kategorie_idKategorie` )
    REFERENCES `moto_111406`.`Kategorie` (`idKategorie` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Udaje`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Udaje` (
  `idUdaje` INT NOT NULL AUTO_INCREMENT ,
  `Stav` VARCHAR(15) NOT NULL ,
  `Cena` INT(8) NOT NULL ,
  `Vykon` INT(3) NULL ,
  `Objem` INT(4) NULL ,
  `Najeto` INT(7) NOT NULL ,
  `Vyrobeno` INT(4) NOT NULL ,
  `Stk` TINYINT(1) NOT NULL ,
  `Puvod` VARCHAR(20) NOT NULL ,
  `Model_idModel` INT NOT NULL ,
  PRIMARY KEY (`idUdaje`) ,
  INDEX `fk_Udaje_Model1` (`Model_idModel` ASC) ,
  CONSTRAINT `fk_Udaje_Model1`
    FOREIGN KEY (`Model_idModel` )
    REFERENCES `moto_111406`.`Model` (`idModel` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Inzerat`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Inzerat` (
  `idInzerat` INT NOT NULL AUTO_INCREMENT ,
  `Popis` VARCHAR(250) NOT NULL ,
  `Akce` VARCHAR(6) NOT NULL ,
  `Vytvoreno` DATETIME NOT NULL ,
  `Uzivatel_idUzivatel` INT NOT NULL ,
  `Udaje_idUdaje` INT NOT NULL ,
  PRIMARY KEY (`idInzerat`) ,
  INDEX `fk_Inzerat_Uzivatel1` (`Uzivatel_idUzivatel` ASC) ,
  INDEX `fk_Inzerat_Udaje1` (`Udaje_idUdaje` ASC) ,
  CONSTRAINT `fk_Inzerat_Uzivatel1`
    FOREIGN KEY (`Uzivatel_idUzivatel` )
    REFERENCES `moto_111406`.`Uzivatel` (`idUzivatel` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Inzerat_Udaje1`
    FOREIGN KEY (`Udaje_idUdaje` )
    REFERENCES `moto_111406`.`Udaje` (`idUdaje` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Foto`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Foto` (
  `idFoto` INT NOT NULL AUTO_INCREMENT ,
  `url_foto` VARCHAR(45) NOT NULL ,
  `url_minfoto` VARCHAR(45) NOT NULL ,
  `Inzerat_idInzerat` INT NOT NULL ,
  PRIMARY KEY (`idFoto`) ,
  UNIQUE INDEX `url_foto_UNIQUE` (`url_foto` ASC) ,
  UNIQUE INDEX `url_minfoto_UNIQUE` (`url_minfoto` ASC) ,
  INDEX `fk_Foto_Inzerat1` (`Inzerat_idInzerat` ASC) ,
  CONSTRAINT `fk_Foto_Inzerat1`
    FOREIGN KEY (`Inzerat_idInzerat` )
    REFERENCES `moto_111406`.`Inzerat` (`idInzerat` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `moto_111406`.`Admin`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `moto_111406`.`Admin` (
  `idAdmin` INT NOT NULL AUTO_INCREMENT ,
  `Nick` VARCHAR(45) NOT NULL ,
  `Jmeno` VARCHAR(45) NOT NULL ,
  `Prijmeni` VARCHAR(45) NOT NULL ,
  `email` VARCHAR(45) NOT NULL ,
  `prava` INT NOT NULL ,
  PRIMARY KEY (`idAdmin`) ,
  UNIQUE INDEX `Nick_UNIQUE` (`Nick` ASC) )
ENGINE = InnoDB;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

insert into Kraj (Kraj) values ('Vysoina');
insert into Kraj (Kraj) values ('Stedoesk');
insert into Kraj (Kraj) values ('Jihomoravsk');
insert into Kraj (Kraj) values ('Jihoesk');
insert into Kraj (Kraj) values ('Karlovarsk');
insert into Kraj (Kraj) values ('Krlovehradeck');
insert into Kraj (Kraj) values ('Libereck');
insert into Kraj (Kraj) values ('Olomouck');
insert into Kraj (Kraj) values ('Moravskoslezk');
insert into Kraj (Kraj) values ('Pardubick');
insert into Kraj (Kraj) values ('Plzesk');
insert into Kraj (Kraj) values ('steck');
insert into Kraj (Kraj) values ('Zlnsk');

/*kraj vysoina*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Vysoina') ,'Havlkv Brod');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Vysoina') ,'Jihlava');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Vysoina') ,'Pelhimov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Vysoina') ,'Teb');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Vysoina') ,'r nad Szavou');

/*Stredocesky kraj */
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Praha');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Beneov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Beroun');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Kladno');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Koln');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Kutn Hora');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Mlnk');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Mlad Boleslav');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Nymburk');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Pbram');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Stedoesk') ,'Rakovnk');

/*Jihomoravsk */
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihomoravsk') ,'Brno');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihomoravsk') ,'Blansko');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihomoravsk') ,'Vykov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihomoravsk') ,'Hodonn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihomoravsk') ,'Beclav');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihomoravsk') ,'Znojmo');

/*Jihoesk*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihoesk') ,'esk Budjovice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihoesk') ,'esk Krumlov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihoesk') ,'Jindichv Hradec');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihoesk') ,'Psek');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihoesk') ,'Prachatice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihoesk') ,'Strakonice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Jihoesk') ,'Tbor');

/*Karlovarsk*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Karlovarsk') ,'Cheb');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Karlovarsk') ,'Karlovy Vary');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Karlovarsk') ,'Sokolov');

/*Krlovehradeck*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Krlovehradeck') ,'Hradec Krlov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Krlovehradeck') ,'Jin');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Krlovehradeck') ,'Nchod');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Krlovehradeck') ,'Rychnov nad Knnou');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Krlovehradeck') ,'Trutnov');

/*Libereck*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Libereck') ,'esk Lpa');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Libereck') ,'Jablonec nad Nisou');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Libereck') ,'Liberec');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Libereck') ,'Semily');

/*Olomouck*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Olomouck') ,'Jesenk');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Olomouck') ,'Olomouc');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Olomouck') ,'Prostjov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Olomouck') ,'Perov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Olomouck') ,'umperk');

/*Moravskoslezk*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Bruntl');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'esk Tn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Frdek Mstek');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Havov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Krnov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Karvin');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Nov Jin');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Opava');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Tinec');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Moravskoslezk') ,'Ostrava');

/*Pardubick*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Pardubick') ,'Chrudim');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Pardubick') ,'Pardubice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Pardubick') ,'Svitavy');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Pardubick') ,'sti nad Orlic');

/*Plzesk*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Plzesk') ,'Domalice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Plzesk') ,'Klatovy');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Plzesk') ,'Plze');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Plzesk') ,'Rokycany');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Plzesk') ,'Tachov');

/*steck*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'steck') ,'st nad Labem');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'steck') ,'Dn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'steck') ,'Chomutov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'steck') ,'Litomice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'steck') ,'Louny');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'steck') ,'Most');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'steck') ,'Teplice');


/*Zlnsk*/
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Zlnsk') ,'Krom');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Zlnsk') ,'Uhersk Hradit');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Zlnsk') ,'Vsetn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Zlnsk') ,'Zln');


/* Znaka motorky */
insert into Znacka (Znacka) values ('Adamsmoto');
insert into Znacka (Znacka) values ('Aprilia');
insert into Znacka (Znacka) values ('Ardie');
insert into Znacka (Znacka) values ('AWO');

insert into Znacka (Znacka) values ('B.S.A.');
insert into Znacka (Znacka) values ('Babetta');
insert into Znacka (Znacka) values ('Benelli');
insert into Znacka (Znacka) values ('Beta');
insert into Znacka (Znacka) values ('Biaginni');
insert into Znacka (Znacka) values ('Bimota');
insert into Znacka (Znacka) values ('Blata');
insert into Znacka (Znacka) values ('BMW');
insert into Znacka (Znacka) values ('Boatian');
insert into Znacka (Znacka) values ('Buell');

insert into Znacka (Znacka) values ('Cagiva');
insert into Znacka (Znacka) values ('Capirelli');
insert into Znacka (Znacka) values ('CF Moto');
insert into Znacka (Znacka) values ('Champs');
insert into Znacka (Znacka) values ('Chunlan');
insert into Znacka (Znacka) values ('Cimatti');
insert into Znacka (Znacka) values ('CPI');
insert into Znacka (Znacka) values ('Cyborg (Baotian)');

insert into Znacka (Znacka) values ('na');
insert into Znacka (Znacka) values ('Z');

insert into Znacka (Znacka) values ('Daelim');
insert into Znacka (Znacka) values ('Derbi');
insert into Znacka (Znacka) values ('Dirtbike & Pitbike');
insert into Znacka (Znacka) values ('DKW');
insert into Znacka (Znacka) values ('Dnpr');
insert into Znacka (Znacka) values ('Ducati');

insert into Znacka (Znacka) values ('Fantic');

insert into Znacka (Znacka) values ('Garelli');
insert into Znacka (Znacka) values ('Gas Gas');
insert into Znacka (Znacka) values ('Gilera');

insert into Znacka (Znacka) values ('Harley Davidson');
insert into Znacka (Znacka) values ('Hartford');
insert into Znacka (Znacka) values ('Hercules');
insert into Znacka (Znacka) values ('HM');
insert into Znacka (Znacka) values ('Honda');
insert into Znacka (Znacka) values ('Husaberg');
insert into Znacka (Znacka) values ('Husqvarna');
insert into Znacka (Znacka) values ('Hyosung');

insert into Znacka (Znacka) values ('Indian');

insert into Znacka (Znacka) values ('Italjet');
insert into Znacka (Znacka) values ('IZH');

insert into Znacka (Znacka) values ('Jawa');
insert into Znacka (Znacka) values ('Jincheng');
insert into Znacka (Znacka) values ('Jinlun');
insert into Znacka (Znacka) values ('Jmstar');
insert into Znacka (Znacka) values ('Junk');

insert into Znacka (Znacka) values ('Kawasaki');
insert into Znacka (Znacka) values ('Keeway');
insert into Znacka (Znacka) values ('Kentoya');
insert into Znacka (Znacka) values ('Kinroad');
insert into Znacka (Znacka) values ('Kovrov');
insert into Znacka (Znacka) values ('KTM');
insert into Znacka (Znacka) values ('Kymco');

insert into Znacka (Znacka) values ('Laverda');
insert into Znacka (Znacka) values ('Lifan');
insert into Znacka (Znacka) values ('Linhai');
insert into Znacka (Znacka) values ('Loncin');

insert into Znacka (Znacka) values ('Maico');
insert into Znacka (Znacka) values ('Malaguti');
insert into Znacka (Znacka) values ('Manet');
insert into Znacka (Znacka) values ('Matchless');

insert into Znacka (Znacka) values ('MBK');
insert into Znacka (Znacka) values ('Megelli');
insert into Znacka (Znacka) values ('MH');
insert into Znacka (Znacka) values ('Mikilon');
insert into Znacka (Znacka) values ('Minibike');
insert into Znacka (Znacka) values ('Minsk');
insert into Znacka (Znacka) values ('Montesa');
insert into Znacka (Znacka) values ('Moto Guzzi');
insert into Znacka (Znacka) values ('Moto Morini');
insert into Znacka (Znacka) values ('Motoscoot');
insert into Znacka (Znacka) values ('Mp Korado');
insert into Znacka (Znacka) values ('MV Agusta');
insert into Znacka (Znacka) values ('MZ');

insert into Znacka (Znacka) values ('Norton');
insert into Znacka (Znacka) values ('NSU');

insert into Znacka (Znacka) values ('Ogar');
insert into Znacka (Znacka) values ('Ostatn');

insert into Znacka (Znacka) values ('Peda');
insert into Znacka (Znacka) values ('Pentamoto');
insert into Znacka (Znacka) values ('Peugeot');
insert into Znacka (Znacka) values ('Piaggio');
insert into Znacka (Znacka) values ('Pitpro');
insert into Znacka (Znacka) values ('Pitsterpro');

insert into Znacka (Znacka) values ('Polini');
insert into Znacka (Znacka) values ('Praga');
insert into Znacka (Znacka) values ('Premier');
insert into Znacka (Znacka) values ('Puch');

insert into Znacka (Znacka) values ('Rex');
insert into Znacka (Znacka) values ('Rieju');
insert into Znacka (Znacka) values ('Romet');
insert into Znacka (Znacka) values ('Royal Enfield');

insert into Znacka (Znacka) values ('Sachs');
insert into Znacka (Znacka) values ('Sarola');
insert into Znacka (Znacka) values ('Sherco');
insert into Znacka (Znacka) values ('Shineray');
insert into Znacka (Znacka) values ('Siamoto');
insert into Znacka (Znacka) values ('Simson');
insert into Znacka (Znacka) values ('SkyTeam');
insert into Znacka (Znacka) values ('SMC');
insert into Znacka (Znacka) values ('Stomp');
insert into Znacka (Znacka) values ('Sunbeam');
insert into Znacka (Znacka) values ('Suzuki');
insert into Znacka (Znacka) values ('SWM');
insert into Znacka (Znacka) values ('SYM');

insert into Znacka (Znacka) values ('TGB');
insert into Znacka (Znacka) values ('TM');

insert into Znacka (Znacka) values ('TMEC');
insert into Znacka (Znacka) values ('TMZ');
insert into Znacka (Znacka) values ('Tomos');
insert into Znacka (Znacka) values ('Triumph');

insert into Znacka (Znacka) values ('Ural');

insert into Znacka (Znacka) values ('V.D.O. Moto');
insert into Znacka (Znacka) values ('Velocette');
insert into Znacka (Znacka) values ('VeloSolex');
insert into Znacka (Znacka) values ('Vespa');
insert into Znacka (Znacka) values ('Victory');
insert into Znacka (Znacka) values ('VM Motor');
insert into Znacka (Znacka) values ('VOR');
insert into Znacka (Znacka) values ('Voxan');

insert into Znacka (Znacka) values ('X-motos');

insert into Znacka (Znacka) values ('Yamaha');
insert into Znacka (Znacka) values ('Yuki');

insert into Znacka (Znacka) values ('Zanella');
insert into Znacka (Znacka) values ('Zipp');
insert into Znacka (Znacka) values ('Znen');
insert into Znacka (Znacka) values ('Zndapp');


/*Kategorie*/
insert into Kategorie (Kategorie) values ('Chopper & Cruiser');
insert into Kategorie (Kategorie) values ('Cross');
insert into Kategorie (Kategorie) values ('tykolky');
insert into Kategorie (Kategorie) values ('Dtsk moto');
insert into Kategorie (Kategorie) values ('Elektromotor');
insert into Kategorie (Kategorie) values ('Enduro & Funbike');
insert into Kategorie (Kategorie) values ('Minibike');
insert into Kategorie (Kategorie) values ('Moped');
insert into Kategorie (Kategorie) values ('Naked Bike');
insert into Kategorie (Kategorie) values ('Nezaaditeln');
insert into Kategorie (Kategorie) values ('Pitbike & Dirtbike');
insert into Kategorie (Kategorie) values ('Pestavby');
insert into Kategorie (Kategorie) values ('Sidecar');
insert into Kategorie (Kategorie) values ('Silnin cestovn');
insert into Kategorie (Kategorie) values ('Silnin sportovn');
insert into Kategorie (Kategorie) values ('Sktr');
insert into Kategorie (Kategorie) values ('Snn sktr');
insert into Kategorie (Kategorie) values ('Supermot');
insert into Kategorie (Kategorie) values ('Trial');
insert into Kategorie (Kategorie) values ('Trike');
insert into Kategorie (Kategorie) values ('Vetern');
insert into Kategorie (Kategorie) values ('Zvodn moto');

/*Model*/
/*Aprilia -Chopper & Cruiser*/
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'), 
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Chopper & Cruiser'), 'Classic 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Chopper & Cruiser'), 'Classic 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Chopper & Cruiser'), 'Red Rose');
/*Aprilia - Enduro & Funbike*/
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETV 1000 Caponord');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETX 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETX 350');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETX 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'MXV 450');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 600');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 650');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 650 Factory');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 650 Trail');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'RX 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'RX 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'RXV 450');

/*
insert into Kraj (Kraj) values ('Praha a okol');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Praha - msto');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'okol Prahy');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Barrandov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Bohnice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Brank');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Bevnov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Bubene');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'ern Most');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'blice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Dejvice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Hje');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Hloubtn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Hluboepy');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Hodkoviky');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Holeovice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Holyn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Hostiva');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Hradany');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Hrdloezy');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Chodov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Jinonice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Jin Msto');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Karln');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Kbely');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Kobylisy');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Koe');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Kr');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Letany');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Libe');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Liboc');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Mal Strana');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Maleice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Modany');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Motol');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Nov Msto');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Nusle');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Petrovice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Pankrc');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Podol');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Prosek');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Radlice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Radotn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Ruzyn');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'epy');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Smchov');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Star Msto');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Stodlky');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Stranice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Steovice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Suchdol');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Trja');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Vinohrady');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Vokovice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Vrovice');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Vysoany');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Vyehrad');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Zahradn Msto');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'Zlin');
insert into Mesto (Kraj_idKraj, Mesto) values ((SELECT idKraj FROM Kraj WHERE Kraj.Kraj = 'Praha a okol') ,'ikov');
*/

/*Adamsmoto*/
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Adamsmoto'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Chopper & Cruiser'), 'JBW 150-8');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Adamsmoto'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Silnin cestovn'), 'JL 125 C');

/*Aprilia*/
/*Aprilia -Chopper & Cruiser*/
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Chopper & Cruiser'), 'Classic 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Chopper & Cruiser'), 'Classic 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Chopper & Cruiser'), 'Red Rose');
/*Aprilia - Enduro & Funbike*/
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETV 1000 Caponord');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETX 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETX 350');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'ETX 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'MXV 450');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 600');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 650');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 650 Factory');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Pegaso 650 Trail');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'RX 125');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'RX 50');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'RXV 450');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'RXV 550');
insert into Model (Znacka_idZnacka, Kategorie_idKategorie, Model) values (
(SELECT idZnacka FROM Znacka WHERE Znacka.Znacka = 'Aprilia'),
(SELECT idKategorie FROM Kategorie WHERE Kategorie.Kategorie = 'Enduro & Funbike'), 'Tuareg Rally 125');

INSERT INTO `admin` (`idAdmin`, `Nick`, `Jmeno`, `Prijmeni`, `Heslo`, `email`) VALUES
(1, 'Mizerka', 'Vojta', 'Pel', '*AA803D048B666A933E512AA53B36C70174A37D1E', 'vojtapesl@gmail.com');